@@ -41,10 +41,9 @@ import org.apache.activemq.artemis.core.security.SecurityAuth;
 import org.apache.activemq.artemis.protocol.amqp.broker.AMQPConnectionCallback;
 import org.apache.activemq.artemis.protocol.amqp.broker.AMQPSessionCallback;
 import org.apache.activemq.artemis.protocol.amqp.broker.ProtonProtocolManager;
-import org.apache.activemq.artemis.protocol.amqp.connect.federation.AMQPFederationAddressSenderController;
-import org.apache.activemq.artemis.protocol.amqp.connect.federation.AMQPFederationQueueSenderController;
 import org.apache.activemq.artemis.protocol.amqp.connect.mirror.AMQPMirrorControllerSource;
 import org.apache.activemq.artemis.protocol.amqp.exceptions.ActiveMQAMQPException;
+import org.apache.activemq.artemis.protocol.amqp.exceptions.ActiveMQAMQPInternalErrorException;
 import org.apache.activemq.artemis.protocol.amqp.exceptions.ActiveMQAMQPSecurityException;
 import org.apache.activemq.artemis.protocol.amqp.logger.ActiveMQAMQPProtocolLogger;
 import org.apache.activemq.artemis.protocol.amqp.logger.ActiveMQAMQPProtocolMessageBundle;
@@ -127,7 +126,9 @@ public class AMQPConnectionContext extends ProtonInitializable implements EventH
 
    private final boolean useCoreSubscriptionNaming;
 
-   /** Outgoing means created by the AMQP Bridge */
+   /**
+    * Outgoing means created by the AMQP Bridge
+    */
    private final boolean bridgeConnection;
 
    private final ScheduleOperator scheduleOp = new ScheduleOperator(new ScheduleRunnable());
@@ -207,15 +208,12 @@ public class AMQPConnectionContext extends ProtonInitializable implements EventH
    }
 
    /**
-    * Adds a listener that will be invoked any time an AMQP link is remotely closed
-    * before having been closed on this end of the connection.
+    * Adds a listener that will be invoked any time an AMQP link is remotely closed before having been closed on this
+    * end of the connection.
     *
-    * @param id
-    *    A unique ID assigned to the listener used to later remove it if needed.
-    * @param linkCloseListener
-    *    The instance of a closed listener.
-    *
-    * @return this connection context instance.
+    * @param id                A unique ID assigned to the listener used to later remove it if needed.
+    * @param linkCloseListener The instance of a closed listener.
+    * @return this connection context instance
     */
    public AMQPConnectionContext addLinkRemoteCloseListener(String id, LinkCloseListener linkCloseListener) {
       linkCloseListeners.put(id, linkCloseListener);
@@ -225,17 +223,15 @@ public class AMQPConnectionContext extends ProtonInitializable implements EventH
    /**
     * Remove the link remote close listener that is identified by the given ID.
     *
-    * @param id
-    *    The unique ID assigned to the listener when it was added.
+    * @param id The unique ID assigned to the listener when it was added.
     */
    public void removeLinkRemoteCloseListener(String id) {
       linkCloseListeners.remove(id);
    }
 
    /**
-    * Clear all link remote close listeners, usually done before connection
-    * termination to avoid any remote close events triggering processing
-    * after the connection shutdown has already started.
+    * Clear all link remote close listeners, usually done before connection termination to avoid any remote close events
+    * triggering processing after the connection shutdown has already started.
     */
    public void clearLinkRemoteCloseListeners() {
       linkCloseListeners.clear();
@@ -330,9 +326,9 @@ public class AMQPConnectionContext extends ProtonInitializable implements EventH
    public void close(ErrorCondition errorCondition) {
       Future<?> scheduledFuture = scheduledFutureRef.getAndSet(null);
 
-      if (scheduledPool instanceof ThreadPoolExecutor && scheduledFuture != null &&
-         scheduledFuture != VOID_FUTURE && scheduledFuture instanceof Runnable) {
-         if (!((ThreadPoolExecutor) scheduledPool).remove((Runnable) scheduledFuture) &&
+      if (scheduledPool instanceof ThreadPoolExecutor executor && scheduledFuture != null &&
+         scheduledFuture != VOID_FUTURE && scheduledFuture instanceof Runnable runnable) {
+         if (!executor.remove(runnable) &&
             !scheduledFuture.isCancelled() && !scheduledFuture.isDone()) {
             ActiveMQAMQPProtocolLogger.LOGGER.cantRemovingScheduledTask();
          }
@@ -408,10 +404,8 @@ public class AMQPConnectionContext extends ProtonInitializable implements EventH
       link.setSource(link.getRemoteSource());
       link.setTarget(link.getRemoteTarget());
 
-      if (link instanceof Receiver) {
-         Receiver receiver = (Receiver) link;
-         if (link.getRemoteTarget() instanceof Coordinator) {
-            Coordinator coordinator = (Coordinator) link.getRemoteTarget();
+      if (link instanceof Receiver receiver) {
+         if (link.getRemoteTarget() instanceof Coordinator coordinator) {
             protonSession.addTransactionHandler(coordinator, receiver);
          } else if (isReplicaTarget(receiver)) {
             handleReplicaTargetLinkOpened(protonSession, receiver);
@@ -425,9 +419,9 @@ public class AMQPConnectionContext extends ProtonInitializable implements EventH
       } else {
          final Sender sender = (Sender) link;
          if (isFederationAddressReceiver(sender)) {
-            protonSession.addSender(sender, new AMQPFederationAddressSenderController(protonSession));
+            protonSession.addFederationAddressSender(sender);
          } else if (isFederationQueueReceiver(sender)) {
-            protonSession.addSender(sender, new AMQPFederationQueueSenderController(protonSession));
+            protonSession.addFederationQueueSender(sender);
          } else if (isFederationEventLink(sender)) {
             protonSession.addFederationEventDispatcher(sender);
          } else {
@@ -457,15 +451,6 @@ public class AMQPConnectionContext extends ProtonInitializable implements EventH
          return;
       }
 
-      // We need to check if the remote desires to send us tunneled core messages or not, and if
-      // we support that we need to offer that back so it knows it can actually do core tunneling.
-      if (verifyDesiredCapability(receiver, AmqpSupport.CORE_MESSAGE_TUNNELING_SUPPORT)) {
-         receiver.setOfferedCapabilities(new Symbol[] {AMQPMirrorControllerSource.MIRROR_CAPABILITY,
-                                                       AmqpSupport.CORE_MESSAGE_TUNNELING_SUPPORT});
-      } else {
-         receiver.setOfferedCapabilities(new Symbol[]{AMQPMirrorControllerSource.MIRROR_CAPABILITY});
-      }
-
       protonSession.addReplicaTarget(receiver);
    }
 
@@ -654,9 +639,9 @@ public class AMQPConnectionContext extends ProtonInitializable implements EventH
       initialize();
 
       /*
-       * This can be null which is in effect an empty map, also we really don't need to check this for in bound connections
-       * but its here in case we add support for outbound connections.
-       * */
+       * This can be null which is in effect an empty map, also we really don't need to check this for in bound
+       * connections but its here in case we add support for outbound connections.
+       */
       if (connection.getRemoteProperties() == null || !connection.getRemoteProperties().containsKey(CONNECTION_OPEN_FAILED)) {
          long nextKeepAliveTime = handler.tick(true);
 
@@ -676,8 +661,8 @@ public class AMQPConnectionContext extends ProtonInitializable implements EventH
       SASLResult saslResult = getSASLResult();
       if (saslResult != null) {
          user = saslResult.getUser();
-         if (saslResult instanceof PlainSASLResult) {
-            password = ((PlainSASLResult) saslResult).getPassword();
+         if (saslResult instanceof PlainSASLResult plainSASLResult) {
+            password = plainSASLResult.getPassword();
          }
       }
 
@@ -750,6 +735,40 @@ public class AMQPConnectionContext extends ProtonInitializable implements EventH
       }
    }
 
+   @Override
+   public void onTransportError(Transport transport) throws Exception {
+      final String errorMessage = transport.getCondition() != null && transport.getCondition().getDescription() != null ?
+         transport.getCondition().getDescription() : "Unknown Internal Error";
+
+      // Cleanup later after the any pending work gets sent to the remote via an IO flush.
+      runLater(() -> connectionCallback.getProtonConnectionDelegate().fail(new ActiveMQAMQPInternalErrorException(errorMessage)));
+   }
+
+   @Override
+   public void onLocalClose(Connection connection) {
+      handler.requireHandler();
+
+      // If the connection delegate is marked as destroyed the IO connection is closed
+      // or closing and will never hear back from the remote with a matching Close
+      // performative from the peer on the other side. In this case we should allow the
+      // sessions a chance to clean up any local sender or receiver bindings.
+      if (connectionCallback.getProtonConnectionDelegate().isDestroyed()) {
+         for (AMQPSessionContext protonSession : sessions.values()) {
+            try {
+               protonSession.close();
+            } catch (Exception e) {
+               // We are closing so ignore errors from attempts to cleanup
+               logger.trace("Caught error while handling local connection close: ", e);
+            }
+         }
+
+         sessions.clear();
+
+         // Try and flush any pending work if the IO hasn't yet been closed.
+         handler.flushBytes();
+      }
+   }
+
    @Override
    public void onRemoteClose(Connection connection) {
       handler.requireHandler();
@@ -866,8 +885,7 @@ public class AMQPConnectionContext extends ProtonInitializable implements EventH
    public void onLocalDetach(Link link) throws Exception {
       handler.requireHandler();
       Object context = link.getContext();
-      if (context instanceof ProtonServerSenderContext) {
-         ProtonServerSenderContext senderContext = (ProtonServerSenderContext) context;
+      if (context instanceof ProtonServerSenderContext senderContext) {
          senderContext.close(false);
       }
    }
@@ -900,8 +918,8 @@ public class AMQPConnectionContext extends ProtonInitializable implements EventH
          String password = null;
          SASLResult saslResult = getSASLResult();
          if (saslResult != null) {
-            if (saslResult instanceof PlainSASLResult) {
-               password = ((PlainSASLResult) saslResult).getPassword();
+            if (saslResult instanceof PlainSASLResult plainSASLResult) {
+               password = plainSASLResult.getPassword();
             }
          }
 
