@@ -64,6 +64,8 @@ public class MQTTSession {
 
    private MQTTProtocolManager protocolManager;
 
+   private MQTTStateManager stateManager;
+
    private boolean clean;
 
    private WildcardConfiguration wildcardConfiguration;
@@ -80,6 +82,7 @@ public class MQTTSession {
                       WildcardConfiguration wildcardConfiguration) throws Exception {
       this.protocolHandler = protocolHandler;
       this.protocolManager = protocolManager;
+      this.stateManager = protocolManager.getStateManager();
       this.wildcardConfiguration = wildcardConfiguration;
 
       this.connection = connection;
@@ -87,7 +90,7 @@ public class MQTTSession {
       mqttConnectionManager = new MQTTConnectionManager(this);
       mqttPublishManager = new MQTTPublishManager(this, protocolManager.isCloseMqttConnectionOnPublishAuthorizationFailure());
       sessionCallback = new MQTTSessionCallback(this, connection);
-      subscriptionManager = new MQTTSubscriptionManager(this);
+      subscriptionManager = new MQTTSubscriptionManager(this, stateManager);
       retainMessageManager = new MQTTRetainMessageManager(this);
 
       state = MQTTSessionState.DEFAULT;
@@ -95,14 +98,21 @@ public class MQTTSession {
       logger.debug("MQTT session created: {}", id);
    }
 
-   // Called after the client has Connected.
-   synchronized void start() throws Exception {
+   /*
+    * This method is only called by MQTTConnectionManager.connect
+    * which is synchronized with MQTTConnectionManager.disconnect
+    */
+   void start() throws Exception {
       mqttPublishManager.start();
       subscriptionManager.start();
       stopped = false;
    }
 
-   synchronized void stop(boolean failure) throws Exception {
+   /*
+    * This method is only called by MQTTConnectionManager.disconnect
+    * which is synchronized with MQTTConnectionManager.connect
+    */
+   void stop(boolean failure) throws Exception {
       state.setFailed(failure);
 
       if (!stopped) {
@@ -112,19 +122,17 @@ public class MQTTSession {
 
          if (serverSession != null) {
             serverSession.stop();
-            serverSession.close(false);
+            serverSession.close(failure);
          }
 
          if (internalServerSession != null) {
             internalServerSession.stop();
-            internalServerSession.close(false);
+            internalServerSession.close(failure);
          }
 
-         if (state != null) {
-            state.setAttached(false);
-            state.setDisconnectedTime(System.currentTimeMillis());
-            state.clearTopicAliases();
-         }
+         state.setAttached(false);
+         state.setDisconnectedTime(System.currentTimeMillis());
+         state.clearTopicAliases();
 
          if (getVersion() == MQTTVersion.MQTT_5) {
             if (state.getClientSessionExpiryInterval() == 0) {
@@ -133,9 +141,7 @@ public class MQTTSession {
                   sendWillMessage();
                }
                clean(false);
-               protocolManager.removeSessionState(connection.getClientID());
-            } else {
-               state.setDisconnectedTime(System.currentTimeMillis());
+               stateManager.removeSessionState(connection.getClientID());
             }
          } else {
             if (state.isWill() && failure) {
@@ -143,7 +149,7 @@ public class MQTTSession {
             }
             if (isClean()) {
                clean(false);
-               protocolManager.removeSessionState(connection.getClientID());
+               stateManager.removeSessionState(connection.getClientID());
             }
          }
       }
@@ -226,6 +232,10 @@ public class MQTTSession {
       return protocolManager;
    }
 
+   MQTTStateManager getStateManager() {
+      return stateManager;
+   }
+
    void clean(boolean enforceSecurity) throws Exception {
       subscriptionManager.clean(enforceSecurity);
       mqttPublishManager.clean();
@@ -290,6 +300,9 @@ public class MQTTSession {
 
    @Override
    public String toString() {
-      return "MQTTSession[coreSessionId: " + (serverSession != null ? serverSession.getName() : "null") + "]";
+      return "MQTTSession[" +
+         "coreSessionId: " + (serverSession != null ? serverSession.getName() : "null") +
+         ", clientId: " + state.getClientId() +
+         "]";
    }
 }
