@@ -30,6 +30,7 @@ import java.util.Collections;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
+import java.util.Objects;
 import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ScheduledExecutorService;
@@ -59,6 +60,7 @@ import org.apache.activemq.artemis.api.core.management.DivertControl;
 import org.apache.activemq.artemis.api.core.management.ManagementHelper;
 import org.apache.activemq.artemis.api.core.management.ObjectNameBuilder;
 import org.apache.activemq.artemis.api.core.management.QueueControl;
+import org.apache.activemq.artemis.api.core.management.RemoteBrokerConnectionControl;
 import org.apache.activemq.artemis.api.core.management.ResourceNames;
 import org.apache.activemq.artemis.core.config.ClusterConnectionConfiguration;
 import org.apache.activemq.artemis.core.config.Configuration;
@@ -75,6 +77,7 @@ import org.apache.activemq.artemis.core.management.impl.DivertControlImpl;
 import org.apache.activemq.artemis.core.management.impl.JGroupsChannelBroadcastGroupControlImpl;
 import org.apache.activemq.artemis.core.management.impl.JGroupsFileBroadcastGroupControlImpl;
 import org.apache.activemq.artemis.core.management.impl.QueueControlImpl;
+import org.apache.activemq.artemis.core.management.impl.RemoteBrokerConnectionControlImpl;
 import org.apache.activemq.artemis.core.message.impl.CoreMessage;
 import org.apache.activemq.artemis.core.messagecounter.MessageCounter;
 import org.apache.activemq.artemis.core.messagecounter.MessageCounterManager;
@@ -94,6 +97,7 @@ import org.apache.activemq.artemis.core.server.BrokerConnection;
 import org.apache.activemq.artemis.core.server.Divert;
 import org.apache.activemq.artemis.core.server.Queue;
 import org.apache.activemq.artemis.core.server.QueueFactory;
+import org.apache.activemq.artemis.core.server.RemoteBrokerConnection;
 import org.apache.activemq.artemis.core.server.cluster.Bridge;
 import org.apache.activemq.artemis.core.server.cluster.BroadcastGroup;
 import org.apache.activemq.artemis.core.server.cluster.ClusterConnection;
@@ -244,6 +248,8 @@ public class ManagementServiceImpl implements ManagementService {
          metricsManager.registerBrokerGauge(builder -> {
             builder.build(BrokerMetricNames.CONNECTION_COUNT, messagingServer, metrics -> (double) messagingServer.getConnectionCount(), ActiveMQServerControl.CONNECTION_COUNT_DESCRIPTION, Collections.emptyList());
             builder.build(BrokerMetricNames.TOTAL_CONNECTION_COUNT, messagingServer, metrics -> (double) messagingServer.getTotalConnectionCount(), ActiveMQServerControl.TOTAL_CONNECTION_COUNT_DESCRIPTION, Collections.emptyList());
+            builder.build(BrokerMetricNames.SESSION_COUNT, messagingServer, metrics -> (double) messagingServer.getSessionCount(), ActiveMQServerControl.SESSION_COUNT_DESCRIPTION, Collections.emptyList());
+            builder.build(BrokerMetricNames.TOTAL_SESSION_COUNT, messagingServer, metrics -> (double) messagingServer.getTotalSessionCount(), ActiveMQServerControl.TOTAL_SESSION_COUNT_DESCRIPTION, Collections.emptyList());
             builder.build(BrokerMetricNames.ADDRESS_MEMORY_USAGE, messagingServer, metrics -> (double) messagingServerControl.getAddressMemoryUsage(), ActiveMQServerControl.ADDRESS_MEMORY_USAGE_DESCRIPTION, Collections.emptyList());
             builder.build(BrokerMetricNames.ADDRESS_MEMORY_USAGE_PERCENTAGE, messagingServer, metrics -> (double) messagingServerControl.getAddressMemoryUsagePercentage(), ActiveMQServerControl.ADDRESS_MEMORY_USAGE_PERCENTAGE_DESCRIPTION, Collections.emptyList());
             builder.build(BrokerMetricNames.DISK_STORE_USAGE, messagingServer, metrics -> messagingServer.getDiskStoreUsage(), ActiveMQServerControl.DISK_STORE_USAGE_DESCRIPTION, Collections.emptyList());
@@ -284,6 +290,7 @@ public class ManagementServiceImpl implements ManagementService {
                builder.build(AddressMetricNames.UNROUTED_MESSAGE_COUNT, addressInfo, metrics -> (double) addressInfo.getUnRoutedMessageCount(), AddressControl.UNROUTED_MESSAGE_COUNT_DESCRIPTION, Collections.emptyList());
                builder.build(AddressMetricNames.ADDRESS_SIZE, addressInfo, metrics -> (double) addressControl.getAddressSize(), AddressControl.ADDRESS_SIZE_DESCRIPTION, Collections.emptyList());
                builder.build(AddressMetricNames.PAGES_COUNT, addressInfo, metrics -> (double) addressControl.getNumberOfPages(), AddressControl.NUMBER_OF_PAGES_DESCRIPTION, Collections.emptyList());
+               builder.build(AddressMetricNames.LIMIT_PERCENT, addressInfo, metrics -> (double) addressControl.getAddressLimitPercent(), AddressControl.LIMIT_PERCENT_DESCRIPTION, Collections.emptyList());
             });
          }
       }
@@ -323,7 +330,7 @@ public class ManagementServiceImpl implements ManagementService {
       if (messagingServer != null) { // messagingServer could be null on certain unit tests where metrics are not relevant
          MetricsManager metricsManager = messagingServer.getMetricsManager();
          if (metricsManager != null) {
-            metricsManager.registerQueueGauge(queue.getAddress().toString(), queue.getName().toString(), (builder) -> {
+            metricsManager.registerQueueGauge(queue.getAddress().toString(), queue.getName().toString(), queue.isTemporary(), (builder) -> {
                builder.build(QueueMetricNames.MESSAGE_COUNT, queue, metrics -> (double) queue.getMessageCount(), QueueControl.MESSAGE_COUNT_DESCRIPTION, Collections.emptyList());
                builder.build(QueueMetricNames.DURABLE_MESSAGE_COUNT, queue, metrics -> (double) queue.getDurableMessageCount(), QueueControl.DURABLE_MESSAGE_COUNT_DESCRIPTION, Collections.emptyList());
                builder.build(QueueMetricNames.PERSISTENT_SIZE, queue, metrics -> (double) queue.getPersistentSize(), QueueControl.PERSISTENT_SIZE_DESCRIPTION, Collections.emptyList());
@@ -402,12 +409,12 @@ public class ManagementServiceImpl implements ManagementService {
       broadcastGroup.setNotificationService(this);
       BroadcastEndpointFactory endpointFactory = configuration.getEndpointFactory();
       BaseBroadcastGroupControl control = null;
-      if (endpointFactory instanceof UDPBroadcastEndpointFactory) {
-         control = new BroadcastGroupControlImpl(broadcastGroup, storageManager, configuration, (UDPBroadcastEndpointFactory) endpointFactory);
-      } else if (endpointFactory instanceof JGroupsFileBroadcastEndpointFactory) {
-         control = new JGroupsFileBroadcastGroupControlImpl(broadcastGroup, storageManager, configuration, (JGroupsFileBroadcastEndpointFactory) endpointFactory);
-      } else if (endpointFactory instanceof ChannelBroadcastEndpointFactory) {
-         control = new JGroupsChannelBroadcastGroupControlImpl(broadcastGroup, storageManager, configuration, (ChannelBroadcastEndpointFactory) endpointFactory);
+      if (endpointFactory instanceof UDPBroadcastEndpointFactory factory) {
+         control = new BroadcastGroupControlImpl(broadcastGroup, storageManager, configuration, factory);
+      } else if (endpointFactory instanceof JGroupsFileBroadcastEndpointFactory factory) {
+         control = new JGroupsFileBroadcastGroupControlImpl(broadcastGroup, storageManager, configuration, factory);
+      } else if (endpointFactory instanceof ChannelBroadcastEndpointFactory factory) {
+         control = new JGroupsChannelBroadcastGroupControlImpl(broadcastGroup, storageManager, configuration, factory);
       } else {
          control = new BaseBroadcastGroupControlImpl(broadcastGroup, storageManager, configuration);
       }
@@ -434,6 +441,33 @@ public class ManagementServiceImpl implements ManagementService {
       unregisterFromRegistry(ResourceNames.BROKER_CONNECTION + name);
    }
 
+   @Override
+   public void registerRemoteBrokerConnection(RemoteBrokerConnection brokerConnection) throws Exception {
+      final String nodeId = brokerConnection.getNodeId();
+      final String name = brokerConnection.getName();
+
+      Objects.requireNonNull(nodeId, "Remote Node ID must be a non-null value");
+      Objects.requireNonNull(name, "Remote connection name must be a non-null value");
+
+      if (nodeId.isBlank()) {
+         throw new IllegalArgumentException("Remote node ID must be a non-empty string value");
+      }
+
+      if (name.isBlank()) {
+         throw new IllegalArgumentException("Remote connection name must be a non-empty string value");
+      }
+
+      RemoteBrokerConnectionControl control = new RemoteBrokerConnectionControlImpl(brokerConnection, storageManager);
+      registerInJMX(objectNameBuilder.getRemoteBrokerConnectionObjectName(nodeId, name), control);
+      registerInRegistry(ResourceNames.REMOTE_BROKER_CONNECTION + nodeId + "." + name, control);
+   }
+
+   @Override
+   public void unregisterRemoteBrokerConnection(String nodeId, String name) throws Exception {
+      unregisterFromJMX(objectNameBuilder.getRemoteBrokerConnectionObjectName(nodeId, name));
+      unregisterFromRegistry(ResourceNames.REMOTE_BROKER_CONNECTION + nodeId + "." + name);
+   }
+
    @Override
    public void registerBridge(final Bridge bridge) throws Exception {
       bridge.setNotificationService(this);
@@ -523,8 +557,8 @@ public class ManagementServiceImpl implements ManagementService {
             ActiveMQServerLogger.LOGGER.managementOperationError(operation, resourceName, e);
             reply.putBooleanProperty(ManagementHelper.HDR_OPERATION_SUCCEEDED, false);
             String exceptionMessage;
-            if (e instanceof InvocationTargetException) {
-               exceptionMessage = ((InvocationTargetException) e).getTargetException().getMessage();
+            if (e instanceof InvocationTargetException invocationTargetException) {
+               exceptionMessage = invocationTargetException.getTargetException().getMessage();
             } else {
                exceptionMessage = e.getMessage();
             }
@@ -544,8 +578,8 @@ public class ManagementServiceImpl implements ManagementService {
                ActiveMQServerLogger.LOGGER.managementAttributeError(attribute, resourceName, e);
                reply.putBooleanProperty(ManagementHelper.HDR_OPERATION_SUCCEEDED, false);
                String exceptionMessage;
-               if (e instanceof InvocationTargetException) {
-                  exceptionMessage = ((InvocationTargetException) e).getTargetException().getMessage();
+               if (e instanceof InvocationTargetException invocationTargetException) {
+                  exceptionMessage = invocationTargetException.getTargetException().getMessage();
                } else {
                   exceptionMessage = e.getMessage();
                }
@@ -670,7 +704,7 @@ public class ManagementServiceImpl implements ManagementService {
          messageCounterManager.start();
       }
 
-      /**
+      /*
        * Ensure the management notification address is created otherwise if auto-create-address = false then cluster
        * bridges won't be able to connect.
        */
@@ -789,9 +823,8 @@ public class ManagementServiceImpl implements ManagementService {
             }
          }
 
-         // start sending notification *messages* only when server has initialised
-         // Note at backup initialisation we don't want to send notifications either
-         // https://jira.jboss.org/jira/browse/HORNETQ-317
+         // Start sending notification *messages* only when server has initialised. Note at backup initialisation we
+         // don't want to send notifications either.
          if (messagingServer == null || !messagingServer.isActive()) {
             logger.debug("ignoring message {} as the server is not initialized", notification);
             return;
@@ -917,10 +950,9 @@ public class ManagementServiceImpl implements ManagementService {
    }
 
    /**
-    * Correlate management responses using the Correlation ID Pattern, if the request supplied a correlation id,
-    * or fallback to the Message ID Pattern providing the request had a message id.
-
-    * @param request
+    * Correlate management responses using the Correlation ID Pattern, if the request supplied a correlation id, or
+    * fallback to the Message ID Pattern providing the request had a message id.
+    *
     * @return correlation identify
     */
    private Object getCorrelationIdentity(final Message request) {
