@@ -49,6 +49,7 @@ import org.apache.activemq.artemis.core.server.BrokerConnection;
 import org.apache.activemq.artemis.core.server.Divert;
 import org.apache.activemq.artemis.core.server.Queue;
 import org.apache.activemq.artemis.core.server.QueueFactory;
+import org.apache.activemq.artemis.core.server.RemoteBrokerConnection;
 import org.apache.activemq.artemis.core.server.management.GuardInvocationHandler;
 import org.apache.activemq.artemis.core.server.routing.ConnectionRouter;
 import org.apache.activemq.artemis.core.server.cluster.Bridge;
@@ -68,9 +69,8 @@ import org.apache.activemq.artemis.utils.collections.ConcurrentHashSet;
 import org.junit.jupiter.api.Test;
 
 /**
- * this is testing the case for resending notifications from RemotingGroupHandler
- * There is a small window where you could receive notifications wrongly
- * this test will make sure the component would play well with that notification
+ * this is testing the case for resending notifications from RemotingGroupHandler There is a small window where you
+ * could receive notifications wrongly this test will make sure the component would play well with that notification
  */
 public class ClusteredResetMockTest extends ServerTestBase {
 
@@ -110,7 +110,7 @@ public class ClusteredResetMockTest extends ServerTestBase {
 
          assertTrue(latchSends.await(10, TimeUnit.SECONDS));
 
-         HashSet<SimpleString> codesAsked = new HashSet<>();
+         Set<SimpleString> codesAsked = new HashSet<>();
 
          for (Notification notification : fake.pendingNotifications) {
             codesAsked.add(notification.getProperties().getSimpleStringProperty(ManagementHelper.HDR_PROPOSAL_GROUP_ID));
@@ -418,5 +418,15 @@ public class ClusteredResetMockTest extends ServerTestBase {
       public void removeNotificationListener(NotificationListener listener) {
 
       }
+
+      @Override
+      public void registerRemoteBrokerConnection(RemoteBrokerConnection brokerConnection) throws Exception {
+
+      }
+
+      @Override
+      public void unregisterRemoteBrokerConnection(String nodeId, String name) throws Exception {
+
+      }
    }
 }
