@@ -71,9 +71,8 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 /**
- * Manages the life-cycle of an ActiveMQ Broker. A BrokerService consists of a
- * number of transport connectors, network connectors and a bunch of properties
- * which can be used to configure the broker as its lazily created.
+ * Manages the life-cycle of an ActiveMQ Broker. A BrokerService consists of a number of transport connectors, network
+ * connectors and a bunch of properties which can be used to configure the broker as its lazily created.
  */
 public class BrokerService implements Service {
 
@@ -109,7 +108,7 @@ public class BrokerService implements Service {
 
    private TemporaryFolder tmpfolder;
 
-   public static WeakHashMap<Broker, Exception> map = new WeakHashMap<>();
+   public static Map<Broker, Exception> map = new WeakHashMap<>();
 
    static {
       InputStream in;
