@@ -36,6 +36,7 @@ import javax.jms.Topic;
 import java.lang.invoke.MethodHandles;
 import java.net.URI;
 import java.util.HashSet;
+import java.util.Set;
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
@@ -59,7 +60,7 @@ import org.apache.activemq.artemis.protocol.amqp.connect.mirror.AMQPMirrorContro
 import org.apache.activemq.artemis.protocol.amqp.connect.mirror.AMQPMirrorMessageFactory;
 import org.apache.activemq.artemis.tests.integration.amqp.AmqpClientTestSupport;
 import org.apache.activemq.artemis.tests.util.CFUtil;
-import org.apache.activemq.artemis.tests.util.RandomUtil;
+import org.apache.activemq.artemis.utils.RandomUtil;
 import org.apache.activemq.artemis.utils.UUIDGenerator;
 import org.apache.activemq.artemis.utils.Wait;
 import org.apache.activemq.artemis.utils.collections.LinkedListIterator;
@@ -132,7 +133,7 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
       server_2.stop();
 
       server.start();
-      assertTrue(server.locateQueue("sometest") == null);
+      assertNull(server.locateQueue("sometest"));
       Wait.assertTrue(server::isActive);
       server_2.start();
       // if this does not succeed the catch up did not arrive at the other server
@@ -202,7 +203,7 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
 
       server_2.start();
 
-      SimpleString queueName = RandomUtil.randomSimpleString();
+      SimpleString queueName = RandomUtil.randomUUIDSimpleString();
 
       server_2.addAddressInfo(new AddressInfo(queueName).setAutoCreated(false));
       server_2.createQueue(QueueConfiguration.of(queueName).setDurable(true));
@@ -215,7 +216,7 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
       Wait.assertTrue(() -> server_2.locateQueue(queueName) == null);
       Thread.sleep(100);
 
-      assertTrue(server.locateQueue(queueName) != null, "Queue was removed when it was configured to not remove it");
+      assertNotNull(server.locateQueue(queueName), "Queue was removed when it was configured to not remove it");
 
       server_2.stop();
       server.stop();
@@ -261,8 +262,8 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
          Wait.assertTrue(() -> server.getAddressInfo(ADDRESS_NAME) != null);
       } else {
          Thread.sleep(250); // things are asynchronous, I need to wait some time to make sure things are transferred over
-         assertTrue(server.locateQueue(ADDRESS_NAME) == null);
-         assertTrue(server.getAddressInfo(ADDRESS_NAME) == null);
+         assertNull(server.locateQueue(ADDRESS_NAME));
+         assertNull(server.getAddressInfo(ADDRESS_NAME));
       }
       server_2.stop();
       server.stop();
@@ -301,8 +302,8 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
       server_2.getConfiguration().addAMQPConnection(amqpConnection);
 
       server.start();
-      assertTrue(server.locateQueue("sometest") == null);
-      assertTrue(server.locateQueue("ToBeGone") != null);
+      assertNull(server.locateQueue("sometest"));
+      assertNotNull(server.locateQueue("ToBeGone"));
       Wait.assertTrue(server::isActive);
       server_2.start();
       // if this does not succeed the catch up did not arrive at the other server
@@ -343,7 +344,7 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
       server_2.getConfiguration().addAMQPConnection(amqpConnection);
 
       server.start();
-      assertTrue(server.locateQueue("sometest") == null);
+      assertNull(server.locateQueue("sometest"));
       Wait.assertTrue(server::isActive);
       server_2.start();
       // if this does not succeed the catch up did not arrive at the other server
@@ -401,19 +402,18 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
       if (!large) {
          return "Text " + i;
       } else {
-         StringBuffer buffer = new StringBuffer();
-         while (buffer.length() < 110 * 1024) {
-            buffer.append("Text " + i + " ");
+         StringBuilder sb = new StringBuilder();
+         while (sb.length() < 110 * 1024) {
+            sb.append("Text " + i + " ");
          }
-         return buffer.toString();
+         return sb.toString();
       }
    }
 
    /**
     * This test is validating that annotations sent to the original broker are not translated to the receiving side.
-    * Also annotations could eventually damage the body if the broker did not take that into consideration.
-    * So, this test is sending delivery annotations on messages.
-    * @throws Exception
+    * Also annotations could eventually damage the body if the broker did not take that into consideration. So, this
+    * test is sending delivery annotations on messages.
     */
    @Test
    public void testLargeMessagesWithDeliveryAnnotations() throws Exception {
@@ -482,9 +482,10 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
       }
    }
 
-
-   /** This is setting delivery annotations and sending messages with no address.
-    * The broker should know how to deal with the annotations and no address on the message. */
+   /**
+    * This is setting delivery annotations and sending messages with no address. The broker should know how to deal with
+    * the annotations and no address on the message.
+    */
    @Test
    public void testNoAddressWithAnnotations() throws Exception {
       server.setIdentity("targetServer");
@@ -1081,7 +1082,7 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
       Session sess = conn.createSession(false, Session.AUTO_ACKNOWLEDGE);
       conn.start();
 
-      HashSet<Integer> idsReceived = new HashSet<>();
+      Set<Integer> idsReceived = new HashSet<>();
 
       MessageConsumer consumer = sess.createConsumer(sess.createQueue(getQueueName()));
       for (int i = START_ID; i <= LAST_ID; i++) {
@@ -1117,7 +1118,7 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
       Session sess = conn.createSession(false, Session.AUTO_ACKNOWLEDGE);
       conn.start();
 
-      HashSet<Integer> idsReceived = new HashSet<>();
+      Set<Integer> idsReceived = new HashSet<>();
 
       Topic topic = sess.createTopic(queueName);
 
